Exception: MastermindGenerator::InvalidDifficultyError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/mastermind_generator/difficulty.rb

Overview

Exception for passing invalid difficulty value as an argument to Difficulty.new

Instance Method Summary collapse

Instance Method Details

#messageObject



6
7
8
# File 'lib/mastermind_generator/difficulty.rb', line 6

def message
  "Invalid Difficulty: It must be one of the difficulty levels which you specified in configuration"
end